@@ -7,8 +7,13 @@ from .. import convert_to_xlsx, Services
 @click.command(context_settings=dict(max_content_width=200))
 @click.argument("path", type=click.Path(exists=True))
 @click.option("-w", "--workers", default=6, show_default=True, help="amount of workers")
+@click.option(
+    "-o",
+    "--output",
+    help="output path for xlsx file relative from current location (ends in .xlsx, overwrites)",
+)
 @click.pass_context
-def to_xlsx(ctx, path, workers):
+def to_xlsx(ctx, path, workers, output):
     """ Convert invoice to xlsx """
     # Services available
     spinner = Halo(spinner="dots")
@@ -26,5 +31,6 @@ def to_xlsx(ctx, path, workers):
         None if "validation" not in endpoints else endpoints["validation"],
         ctx.obj["token"],
         workers,
+        output,
     )
     spinner.succeed("Converted invoice(s) to xlsx")
