@@ -14,6 +14,7 @@ def convert_to_xlsx(
     validation_endpoint: str = None,
     token: str = None,
     workers: int = 6,
+    output_path: str = None,
 ):
     """Sends requests to defined Hypatos services for every invoice found in given
     directory. Merges results off all services into one Excel file and writes to
@@ -32,9 +33,27 @@ def convert_to_xlsx(
         token {str} -- API token. (default: {None})
         workers {int} -- Amount of multithread. (default: {6})
     """
+    if not output_path:
+        output_path = f"{os.path.normpath(path).split(os.path.sep)[-1]}.xlsx"
+    else:
+        output_path = f"{os.path.join(os.getcwd(), output_path)}"
+        if not os.path.isdir(os.path.sep.join(output_path.split(os.path.sep)[:-1])):
+            quit("Output directory does not exsist")
+
     # Get requests result
-    result, single_fieldnames, multi_fieldnames, default_cols = run_requests(
-        workers, path, extractor_endpoint, validation_endpoint, token,
+    (
+        result,
+        single_fieldnames,
+        multi_fieldnames,
+        default_cols,
+        vat_validation_result,
+    ) = run_requests(
+        workers,
+        path,
+        extractor_endpoint,
+        vat_validator_endpoint,
+        validation_endpoint,
+        token,
     )
 
     # Structure result
@@ -43,8 +62,7 @@ def convert_to_xlsx(
     )
 
     # Init workbook/sheets
-    processed_dir_name = os.path.normpath(path).split(os.path.sep)[-1]
-    workbook = xlsxwriter.Workbook(f"{processed_dir_name}.xlsx")
+    workbook = xlsxwriter.Workbook(output_path)
     workbook.add_worksheet("single_cardinality")
     workbook.add_worksheet("multi_cardinality")
 
@@ -73,6 +91,9 @@ def convert_to_xlsx(
         validation_endpoint,
     )
 
+    if vat_validation_result:
+        write_vat_validation(vat_validation_result, workbook)
+
     workbook.close()
 
 
@@ -283,3 +304,15 @@ def flatten_invoice(invoice, validation):
 
     traverse_items(entities, probabilities, validation, return_dict)
     return return_dict
+
+
+def write_vat_validation(result, workbook):
+    workbook.add_worksheet("vat_validation")
+    worksheet = workbook.get_worksheet_by_name("vat_validation")
+
+    for idx, row in result.items():
+        count = 0
+        for key, value in row.items():
+            worksheet.write(0, count, key)
+            worksheet.write(idx + 1, count, value)
+            count += 1
