@@ -93,7 +93,7 @@ def merge_validation(result):
 
                 for idx in range(0, len(value)):
                     # Try hack when there is a validation error for a item and previous has not.
-                    entity_got_validation = (
+                    entity_idx_got_validation = (
                         entity_got_validation and str(idx) in validation[entity][0]
                     )
                     try:
@@ -102,11 +102,11 @@ def merge_validation(result):
                             entities[entity][idx],
                             _dict[entity][idx],
                             validation[entity][0][str(idx)][0]
-                            if entity_got_validation
+                            if entity_idx_got_validation
                             else None,
                         )
                         # _dict[entity][idx]["@idx"] = str(idx)
-                        if entity_got_validation:
+                        if entity_idx_got_validation:
                             if entity == "tax":
                                 singular = entity
                             else:
@@ -120,7 +120,9 @@ def merge_validation(result):
                                 validation_idx
                             ] = validation[entity][0][str(idx)][0]
                             del validation[entity][0][str(idx)]
-                            validation[entity][0][singular][idx]["@idx"] = idx
+                            validation[entity][0][singular][validation_idx][
+                                "@idx"
+                            ] = idx
                             validation_idx += 1
                     except (KeyError, IndexError):
                         _dict[entity].pop(-1)
